import { Package as BasePackage, PackageOptions as BasePackageOptions } from '@deep-foundation/deeplinks/imports/package.js';
/**
Represents a deep package

@remarks
Contains name of the package and all the links as the objects with id method which returns the id of the link.

@example
#### Use name field to get the name of the package
```ts
const package = new Package({deep});
const {name: packageName} = package;
```
#### Use id method to get the id of the link
```ts
const package = new Package({deep});
const booleanDependencyTypeLinkId = await package["BooleanDependency"].id();
const networkTypeLinkId = await package["Network"].id();
const noneTypeLinkId = await package["None"].id();
const unknownTypeLinkId = await package["Unknown"].id();
const cellularTypeLinkId = await package["Cellular"].id();
const wifiTypeLinkId = await package["Wifi"].id();
const networkStatusTypeLinkId = await package["NetworkStatus"].id();
```

#### Use idLocal method to get the local id of the link
```ts
const package = new Package({deep});
await package.applyMinilinks();
const booleanDependencyTypeLinkId = package["BooleanDependency"].idLocal();
const networkTypeLinkId = package["Network"].idLocal();
const noneTypeLinkId = package["None"].idLocal();
const unknownTypeLinkId = package["Unknown"].idLocal();
const cellularTypeLinkId = package["Cellular"].idLocal();
const wifiTypeLinkId = package["Wifi"].idLocal();
const networkStatusTypeLinkId = package["NetworkStatus"].idLocal();
```
#### Use name field to get the name of the link
```ts
const package = new Package({deep});
const booleanDependency = package["BooleanDependency"].name;
const network = package["Network"].name;
const none = package["None"].name;
const unknown = package["Unknown"].name;
const cellular = package["Cellular"].name;
const wifi = package["Wifi"].name;
const networkStatus = package["NetworkStatus"].name;
```
*/
export declare class Package extends BasePackage {
    constructor(param: PackageOptions);
    /**
    @example
    #### Use id method to get the id of the BooleanDependency link
    ```ts
    const package = new Package({deep});
    const booleanDependencyTypeLinkId = await package["BooleanDependency"].id();
    ```
    #### Use localId method to get the local id of the BooleanDependency link
    ```ts
    const package = new Package({deep});
    const booleanDependencyTypeLinkId = await package["BooleanDependency"].localId();
    ```
    #### Use name field to get the name of the BooleanDependency link
    ```ts
    const package = new Package({deep});
    const booleanDependency = await package["BooleanDependency"].name;
    ```
    */
    "BooleanDependency": {
        id: () => Promise<number>;
        idLocal: () => number;
        name: string;
    };
    /**
    @example
    #### Use id method to get the id of the Network link
    ```ts
    const package = new Package({deep});
    const networkTypeLinkId = await package["Network"].id();
    ```
    #### Use localId method to get the local id of the Network link
    ```ts
    const package = new Package({deep});
    const networkTypeLinkId = await package["Network"].localId();
    ```
    #### Use name field to get the name of the Network link
    ```ts
    const package = new Package({deep});
    const network = await package["Network"].name;
    ```
    */
    "Network": {
        id: () => Promise<number>;
        idLocal: () => number;
        name: string;
    };
    /**
    @example
    #### Use id method to get the id of the None link
    ```ts
    const package = new Package({deep});
    const noneTypeLinkId = await package["None"].id();
    ```
    #### Use localId method to get the local id of the None link
    ```ts
    const package = new Package({deep});
    const noneTypeLinkId = await package["None"].localId();
    ```
    #### Use name field to get the name of the None link
    ```ts
    const package = new Package({deep});
    const none = await package["None"].name;
    ```
    */
    "None": {
        id: () => Promise<number>;
        idLocal: () => number;
        name: string;
    };
    /**
    @example
    #### Use id method to get the id of the Unknown link
    ```ts
    const package = new Package({deep});
    const unknownTypeLinkId = await package["Unknown"].id();
    ```
    #### Use localId method to get the local id of the Unknown link
    ```ts
    const package = new Package({deep});
    const unknownTypeLinkId = await package["Unknown"].localId();
    ```
    #### Use name field to get the name of the Unknown link
    ```ts
    const package = new Package({deep});
    const unknown = await package["Unknown"].name;
    ```
    */
    "Unknown": {
        id: () => Promise<number>;
        idLocal: () => number;
        name: string;
    };
    /**
    @example
    #### Use id method to get the id of the Cellular link
    ```ts
    const package = new Package({deep});
    const cellularTypeLinkId = await package["Cellular"].id();
    ```
    #### Use localId method to get the local id of the Cellular link
    ```ts
    const package = new Package({deep});
    const cellularTypeLinkId = await package["Cellular"].localId();
    ```
    #### Use name field to get the name of the Cellular link
    ```ts
    const package = new Package({deep});
    const cellular = await package["Cellular"].name;
    ```
    */
    "Cellular": {
        id: () => Promise<number>;
        idLocal: () => number;
        name: string;
    };
    /**
    @example
    #### Use id method to get the id of the Wifi link
    ```ts
    const package = new Package({deep});
    const wifiTypeLinkId = await package["Wifi"].id();
    ```
    #### Use localId method to get the local id of the Wifi link
    ```ts
    const package = new Package({deep});
    const wifiTypeLinkId = await package["Wifi"].localId();
    ```
    #### Use name field to get the name of the Wifi link
    ```ts
    const package = new Package({deep});
    const wifi = await package["Wifi"].name;
    ```
    */
    "Wifi": {
        id: () => Promise<number>;
        idLocal: () => number;
        name: string;
    };
    /**
    @example
    #### Use id method to get the id of the NetworkStatus link
    ```ts
    const package = new Package({deep});
    const networkStatusTypeLinkId = await package["NetworkStatus"].id();
    ```
    #### Use localId method to get the local id of the NetworkStatus link
    ```ts
    const package = new Package({deep});
    const networkStatusTypeLinkId = await package["NetworkStatus"].localId();
    ```
    #### Use name field to get the name of the NetworkStatus link
    ```ts
    const package = new Package({deep});
    const networkStatus = await package["NetworkStatus"].name;
    ```
    */
    "NetworkStatus": {
        id: () => Promise<number>;
        idLocal: () => number;
        name: string;
    };
}
export type PackageOptions = Omit<BasePackageOptions, 'name'>;
